@@ -23,8 +23,10 @@ has 'argv' => (
             I18N::Langinfo->import(qw(langinfo CODESET));
             my $codeset = langinfo(CODESET());
             # TODO Not sure if this is the right place?
-            binmode(STDOUT, ":encoding(UTF-8)")
-                if $codeset =~ m/^UTF-?8$/i;
+            if ($codeset =~ m/^UTF-?8$/i) {
+                binmode(STDOUT, ":encoding(UTF-8)");
+                binmode(STDERR, ":encoding(UTF-8)");
+            }
             return map { decode($codeset,$_) } @ARGV;
         };
         # Fallback to standard
@@ -35,11 +37,11 @@ has 'argv' => (
     },
 );
 
-has 'hints_flags' => (
+has 'hints_novalue' => (
     is              => 'rw',
     isa             => 'ArrayRef[Str]',
     default         => sub { [] },
-); # Flag hints for the parser
+); # No value hints for the parser (such as for flags)
 
 has 'hints_permute' => (
     is              => 'rw',
@@ -57,7 +59,7 @@ has 'elements' => (
 
 sub BUILD {
     my ($self) = @_;
-    
+
     # Register singleton
     $SINGLETON = $self;
     return $self;
@@ -65,7 +67,7 @@ sub BUILD {
 
 sub DEMOLISH {
     my ($self) = @_;
-    
+
     # Unregister singleton if it is stll the same
     $SINGLETON = undef
         if defined $SINGLETON
@@ -82,35 +84,40 @@ sub instance {
 
 sub first_argv {
     my ($self) = @_;
-    
+
     $self->reset_elements;
     return shift(@{$self->argv});
 }
 
 sub _build_elements {
     my ($self) = @_;
-    
+
     my (@elements);
 
     my %options;
     my $lastkey;
-    my $stopprocessing;
-    
+    my $stopprocessing; # flag that is set after ' -- '
+    my $position = 0;
+
+    # Loop all elements of our ARGV copy
     foreach my $element (@{$self->argv}) {
+        # We are behind first ' -- ' occurence: Do not process further
         if ($stopprocessing) {
-            push (@elements,MooseX::App::ParsedArgv::Element->new( 
-                key => $element, 
-                type => 'extra', 
+            push (@elements,MooseX::App::ParsedArgv::Element->new(
+                key => $element,
+                type => 'extra',
             ));
+        # Process element
         } else {
             given ($element) {
-                # Flags
+                # Flags with only one leading dash (-h or -vh)
                 when (m/^-([^-][[:alnum:]]*)$/) {
                     undef $lastkey;
+                    # Split into single letter flags
                     foreach my $flag (split(//,$1)) {
                         unless (defined $options{$flag}) {
-                            $options{$flag} = MooseX::App::ParsedArgv::Element->new( 
-                                key => $flag, 
+                            $options{$flag} = MooseX::App::ParsedArgv::Element->new(
+                                key => $flag,
                                 type => 'option',
                                 raw => $element,
                             );
@@ -118,10 +125,11 @@ sub _build_elements {
                         } else {
                             $options{$flag}->inc_occurrence;
                         }
+                        $options{$flag}->add_value(1,$position);
                         $lastkey = $options{$flag};
                     }
                 }
-                # Key-value combined
+                # Key-value combined (--key=value)
                 when (m/^--([^-=][^=]*)=(.+)$/) {
                     undef $lastkey;
                     my ($key,$value) = ($1,$2);
@@ -135,14 +143,14 @@ sub _build_elements {
                     } else {
                         $options{$key}->inc_occurrence;
                     }
-                    $options{$key}->add_value($value);
+                    $options{$key}->add_value($value,$position);
                 }
-                # Key
-                when (m/^--([^-].*)/) {
-                    my $key = $1;
+                # Keys (--key or --not-key)
+                when (m/^--(not?-)?([^-].*)/) {
+                    my $key = $2;
                     unless (defined $options{$key}) {
-                        $options{$key} = MooseX::App::ParsedArgv::Element->new( 
-                            key => $key, 
+                        $options{$key} = MooseX::App::ParsedArgv::Element->new(
+                            key => $key,
                             type => 'option',
                             raw => $element,
                         );
@@ -150,9 +158,14 @@ sub _build_elements {
                     } else {
                         $options{$key}->inc_occurrence;
                     }
-                    $lastkey = $options{$key};
+                    # This is a boolean key
+                    if ($key ~~ $self->hints_novalue) {
+                        $options{$key}->add_value($1 ? 0:1,$position);
+                    } else {
+                        $lastkey = $options{$key};
+                    }
                 }
-                # Extra values
+                # Extra values - stop processing after this token
                 when ('--') {
                     undef $lastkey;
                     $stopprocessing = 1;
@@ -160,57 +173,66 @@ sub _build_elements {
                 # Value
                 default {
                     if (defined $lastkey) {
-                        # No value
-                        if ($lastkey->key ~~ $self->hints_flags) {
+                        # This is a parameter - last key was a flag
+                        if ($lastkey->key ~~ $self->hints_novalue) {
                             push(@elements,MooseX::App::ParsedArgv::Element->new( key => $element, type => 'parameter' ));
                             undef $lastkey;
                         # Permute values
                         } elsif ($lastkey->key ~~ $self->hints_permute) {
-                            $lastkey->add_value($element);
+                            $lastkey->add_value($element,$position);
                         # Has value
                         } else {
-                            $lastkey->add_value($element);
+                            $lastkey->add_value($element,$position);
                             undef $lastkey;
                         }
                     } else {
                         push(@elements,MooseX::App::ParsedArgv::Element->new( key => $element, type => 'parameter' ));
                     }
                 }
-            } 
+            }
+        }
+        $position++;
+    }
+
+    # Check elements
+    foreach my $element (@elements) {
+        while ($element->has_values < $element->occurrence) {
+            $element->add_value(undef,$position);
+            $position++;
         }
     }
-    
+
     return \@elements;
 }
 
 sub available {
     my ($self,$type) = @_;
-    
+
     my @elements;
     foreach my $element (@{$self->elements}) {
         next
             if $element->consumed;
         next
-            if defined $type 
+            if defined $type
             && $element->type ne $type;
         push(@elements,$element);
-    }  
-    return @elements; 
+    }
+    return @elements;
 }
 
 sub consume {
     my ($self,$type) = @_;
-    
+
     foreach my $element (@{$self->elements}) {
         next
             if $element->consumed;
         next
-            if defined $type 
+            if defined $type
             && $element->type ne $type;
         $element->consume;
         return $element;
-    }  
-    return; 
+    }
+    return;
 }
 
 sub extra {
@@ -224,8 +246,8 @@ sub extra {
             unless $element->type eq 'parameter'
             || $element->type eq 'extra';
         push(@extra,$element->key);
-    }  
-    
+    }
+
     return @extra;
 }
 
@@ -243,7 +265,7 @@ MooseX::App::ParsedArgv - Parses @ARGV
 =head1 SYNOPSIS
 
  use MooseX::App::ParsedArgv;
- my $argv = MooseX::App::ParsedArgv->instance; 
+ my $argv = MooseX::App::ParsedArgv->instance;
  
  foreach my $option ($argv->available('option')) {
      say "Parsed ".$option->key;
@@ -251,7 +273,7 @@ MooseX::App::ParsedArgv - Parses @ARGV
 
 =head1 DESCRIPTION
 
-This is a helper class that holds all options parsed from @ARGV. It is 
+This is a helper class that holds all options parsed from @ARGV. It is
 implemented as a singleton. Unless you are developing a MooseX::App plugin
 you usually do not need to interact with this class.
 
@@ -262,18 +284,18 @@ you usually do not need to interact with this class.
 Create a new MooseX::App::ParsedArgv instance. Needs to be called as soon
 as possible.
 
-=head2 instance 
+=head2 instance
 
 Get the current MooseX::App::ParsedArgv instance. If there is no instance
 a new one will be created.
 
 =head2 argv
 
-Accessor for the initinal @ARGV. 
+Accessor for the initinal @ARGV.
 
 =head2 hints
 
-ArrayRef of attributes that tells the parser which attributes should be 
+ArrayRef of attributes that tells the parser which attributes should be
 regarded as flags without values.
 
 =head2 first_argv
@@ -295,7 +317,7 @@ The array elements will be L<MooseX::App::ParsedArgv::Element> objects.
  OR
  my $option = $self->consume();
 
-Returns the first option/parameter of the local @ARGV that has not yet been 
+Returns the first option/parameter of the local @ARGV that has not yet been
 consumed as a L<MooseX::App::ParsedArgv::Element> object.
 
 =head2 elements
@@ -307,4 +329,4 @@ Returns all parsed options and parameters.
 Returns an array reference of unconsumed positional parameters and
 extra values.
 
-=cut
\ No newline at end of file
+=cut
